aboutsummaryrefslogtreecommitdiffstats
path: root/libmproxy/platform/osx.py
diff options
context:
space:
mode:
Diffstat (limited to 'libmproxy/platform/osx.py')
-rw-r--r--libmproxy/platform/osx.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/libmproxy/platform/osx.py b/libmproxy/platform/osx.py
index 1a474e94..dda5d9af 100644
--- a/libmproxy/platform/osx.py
+++ b/libmproxy/platform/osx.py
@@ -1,16 +1,16 @@
import subprocess
-import lsof
+import pf
"""
Doing this the "right" way by using DIOCNATLOOK on the pf device turns out
to be a pain. Apple has made a number of modifications to the data
structures returned, and compiling userspace tools to test and work with
this turns out to be a pain in the ass. Parsing lsof output is short,
simple, and works.
"""
class Resolver:
- STATECMD = ("sudo", "-n", "/usr/sbin/lsof", "-n", "-P", "-i", "TCP")
+ STATECMD = ("sudo", "-n", "/sbin/pfctl", "-s", "state")
def __init__(self):
pass
@@ -20,4 +20,4 @@ class Resolver:
stxt = subprocess.check_output(self.STATECMD, stderr=subprocess.STDOUT)
except subprocess.CalledProcessError:
return None
- return lsof.lookup(peer[0], peer[1], stxt)
+ return pf.lookup(peer[0], peer[1], stxt)
@@ -1,16 +1,16 @@
to be a pain. Apple has made a number of modifications to the data
structures returned, and compiling userspace tools to test and work with
- this turns out to be a pain in the ass. Parsing lsof output is short,
+ this turns out to be a pain in the ass. Parsing pfctl output is short,
simple, and works.
"""